@@ -1,7 +1,7 @@
-/* Time-stamp: <2007-10-05 03:02:16 poser> */
+/* Time-stamp: <2008-09-30 18:37:17 poser> */
 
 /*
- * Copyright (C) 1993-2007 William J. Poser (billposer@alum.mit.edu).
+ * Copyright (C) 1993-2008 William J. Poser (billposer@alum.mit.edu).
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of version 3 of the GNU General Public License as published by
  * the Free Software Foundation.
@@ -61,11 +61,12 @@ PrintGeneralFlags(FILE *fp)
   fprintf(fp,_("\t-M,--initial-maximum-records <records>\n\t\t\t\tSet initial maximum number of records \n"));
   fprintf(fp,_("\t-m,--line-end-carriage-return\n\t\t\t\tEnd of line is marked by Carriage Return (0x0D)\n"));
   fprintf(fp,_("\t-I,--invert-globally\tInvert sense of comparisons globally\n"));
-  fprintf(fp,_("\t-Q,--check-only\t\tCheck whether input is sorted. Generate no output.\n"));
+  fprintf(fp,_("\t-Q,--check-only\t\tCheck whether input is sorted. Generate no output.\n\t\t\t\tExit status is 0 if input is sorted, 11 if not.\n"));
   fprintf(fp,_("\t-u,--unicode-normalization <Normalization Mode>\n"));
   fprintf(fp,_("\t\tc NFC canonical decomposition then composition (default)\n"));
   fprintf(fp,_("\t\td NFD canonical decomposition\n"));
   fprintf(fp,_("\t\tn no normalization\n"));
+  fprintf(fp,_("\t-P,--random-seed <seed>\n"));
   fprintf(fp,_("\t-1,--in  <Input File Name>\n"));
   fprintf(fp,_("\t-2,--out <Output File Name>\n"));
   fprintf(fp,_("\t-j,--suppress-log\tSuppress log output\n"));
@@ -129,13 +130,14 @@ void PrintKeySpecificFlags(FILE *fp)
   fprintf(fp,_("\t-X,--exclude-characters <exclusions>\n\t\t\t\tExclude specified characters\n"));
   fprintf(fp,_("\t-i,--invert-locally\tInvert sense of comparisons\n"));
   fprintf(fp,_("\t-R,--reverse-key\tReverse characters of key\n"));
+  fprintf(fp,_("\t-A,--first-char-only\tUse only the first character of the field\n"));
   fputc('\n',fp);				
 }
 
 void
 PrintGNUEquivalences(FILE *fp)
 {
-  fprintf(fp,"GNU sort\t\t\t\tmsort\n");
+  fprintf(fp,"GNU/BSD sort\t\t\t\tmsort\n");
   fprintf(fp,"-c,--check\t\t\t\t-Q,--check-only\n");
   fprintf(fp,"-f,--ignore-case\t\t\t-C,--fold-case\n");
   fprintf(fp,"-g,--general-numeric-sort\t\t-c n,--comparison-type n\n");
@@ -173,6 +175,7 @@ PrintGeneralFlags(FILE *fp)
   fprintf(fp,_("\t-M <records>          Set initial maximum number of records \n"));
   fprintf(fp,_("\t-m                    End of line is marked by Carriage Return (0x0D)\n"));
   fprintf(fp,_("\t-I                    Invert sense of comparisons globally\n"));
+  fprintf(fp,_("\t-P <seed>             Set the random number generator seed.\n"));
   fprintf(fp,_("\t-1 <Input File Name>\n"));
   fprintf(fp,_("\t-2 <Output File Name>\n"));
   fprintf(fp,_("\t-j                    Suppress log output\n"));
@@ -236,13 +239,14 @@ PrintKeySpecificFlags(FILE *fp)
   fprintf(fp,_("\t-X <exclusions>       Exclude specified characters\n"));
   fprintf(fp,_("\t-i                    Invert sense of comparisons\n"));
   fprintf(fp,_("\t-R                    Reverse characters of key\n"));
+  fprintf(fp,_("\t-A                    Use only the first character of the field\n"));
   fputc('\n',fp);				
 }
 
 void
 PrintGNUEquivalences(FILE *fp)
 {
-  fprintf(fp,"GNU sort\t\t\t\tmsort\n");
+  fprintf(fp,"GNU/BSD sort\t\t\t\tmsort\n");
   fprintf(fp,"-c,--check\t\t\t\t-Q\n");
   fprintf(fp,"-f,--ignore-case\t\t\t-C\n");
   fprintf(fp,"-g,--general-numeric-sort\t\t-c n\n");
